*******
Viceroy
*******

A viceroy is someone who is delegating on behalf authority in a colonized land, in case of this library, viceroy runs Javascript unit tests on behalf of Python for easier testing.

See https://viceroy.readthedocs.org for documentation.
